pm4py.algo.discovery.footprints.tree package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.footprints.tree.variants

Module contents
---------------

.. automodule:: pm4py.algo.discovery.footprints.tree
   :members:
   :undoc-members:
   :show-inheritance:
